%if 0%{?fedora} > 12
%global with_python3 1
%else
%global with_python3 0
%endif

# Turn off the brp-python-bytecompile script
%global __os_install_post %(echo '%{__os_install_post}' | sed -e 's!/usr/lib[^[:space:]]*/brp-python-bytecompile[[:space:]].*$!!g')

%global         pkgname Django


# Tests requiring Internet connections are disabled by default
# pass --with internet to run them (e.g. when doing a local rebuild
# for sanity checks before committing)
%bcond_with internet

# one higher than the last Django release, to account for
# dist tags
%global         obs_ver 1.5.5-3

Name:           python-django

Version:        1.11.13
Release:        4%{?dist}
Summary:        A high-level Python Web framework

Group:          Development/Languages
License:        BSD
URL:            http://www.djangoproject.com/
Source0:        https://files.pythonhosted.org/packages/source/D/Django/Django-%{version}.tar.gz

BuildArch:      noarch


%description
Django is a high-level Python Web framework that encourages rapid
development and a clean, pragmatic design. It focuses on automating as
much as possible and adhering to the DRY (Don't Repeat Yourself)
principle.

%package -n     python2-django
Summary:        A high-level Python Web framework
Provides:       python-django = %{version}-%{release}
BuildRequires:  python2-devel
BuildRequires:  python2-bcrypt

# test requirements
#BuildRequires:  py-bcrypt
BuildRequires:  python-docutils
BuildRequires:  python-jinja2
BuildRequires:  python-mock
BuildRequires:  numpy
BuildRequires:  python-pillow
BuildRequires:  PyYAML
BuildRequires:  pytz
%if 0%{?fedora} > 0
BuildRequires:  python-selenium
%endif
BuildRequires:  python-sqlparse
BuildRequires:  python-memcached
Requires:       pytz
Requires:       %{name}-bash-completion = %{version}-%{release}

# allow users to use django with lowercase d
Provides:       django = %{version}-%{release}
Provides:       %{pkgname} = %{version}-%{release}

Provides: bundled(jquery) = 2.2.3
Provides: bundled(xregexp) = 2.0.0

%description -n python2-django
Django is a high-level Python Web framework that encourages rapid
development and a clean, pragmatic design. It focuses on automating as
much as possible and adhering to the DRY (Don't Repeat Yourself)
principle.



%package -n python2-django-doc
Summary:        Documentation for Django
Group:          Documentation
Requires:       %{name} = %{version}-%{release}
Provides:       python-django-docs = %{version}-%{release}

BuildRequires:  python-sphinx

Provides:       django-docs = %{version}-%{release}
Provides:       %{pkgname}-docs = %{version}-%{release}

%description -n python2-django-doc
This package contains the documentation for the Django high-level
Python Web framework.



%package bash-completion
Summary:        bash completion files for Django
BuildRequires:  bash-completion


%description bash-completion
This package contains the bash completion files form Django high-level
Python Web framework.

%if 0%{?with_python3}
%package -n python3-django-doc
Summary:        Documentation for Django
Group:          Documentation
Requires:       python3-django = %{version}-%{release}

%description -n python3-django-doc
This package contains the documentation for the Django high-level
Python Web framework.

%package -n python3-django
Summary:        A high-level Python Web framework
Group:          Development/Languages

Requires:       %{name}-bash-completion = %{version}-%{release}
Requires:       python3-pytz

BuildRequires:  python3-devel
BuildRequires:  python3-bcrypt
# test requirements
#BuildRequires: python3-py-bcrypt
BuildRequires:  python3-docutils
BuildRequires:  python3-jinja2
BuildRequires:  python3-mock
BuildRequires:  python3-numpy
BuildRequires:  python3-pillow
BuildRequires:  python3-PyYAML
BuildRequires:  python3-pytz
BuildRequires:  python3-selenium
BuildRequires:  python3-sqlparse
BuildRequires:  python3-memcached

Provides: bundled(jquery) = 2.2.3
Provides: bundled(xregexp) = 2.0.0

%description -n python3-django
Django is a high-level Python Web framework that encourages rapid
development and a clean, pragmatic design. It focuses on automating as
much as possible and adhering to the DRY (Don't Repeat Yourself)
principle.
%endif

%prep
%autosetup -n %{pkgname}-%{version}


%build
%py2_build

%if 0%{?with_python3}
%py3_build
%endif # with_python3


%install
# must do install of python 3 subpackage first, so that we don't
# overwrite django-admin script with the python 3 version
%if 0%{?with_python3}
%py3_install
mv %{buildroot}%{_bindir}/django-admin.py %{buildroot}%{_bindir}/python3-django-admin
%endif # with_python3

%py2_install

%if 0%{?fedora} > 0
# Manually invoke the python byte compile macro for each path that needs byte
# compilation.
%py_byte_compile %{__python2} %{buildroot}%{python2_sitelib}

%if 0%{?with_python3}
%py_byte_compile %{__python3} %{buildroot}%{python3_sitelib}
%endif # with_python3

%endif

%find_lang django
%find_lang djangojs
# append djangojs.lang to django.lang
cat djangojs.lang >> django.lang

%if 0%{?with_python3}
# When creating Python3 package, separate lang to Python 2 and Python 3 files
grep python3 django.lang > python3-django.lang
grep python2 django.lang > python2-django.lang
mv {python2-,}django.lang
%endif # with_python3

# TODO: mrunge reenable docs build.
#
# docs build triggers some sphinx issue on epel, skipping for now
# build documentation
#(cd docs && mkdir djangohtml && mkdir -p _build/{doctrees,html} && make html)
#cp -ar docs ..

# install man pages
mkdir -p %{buildroot}%{_mandir}/man1/
cp -p docs/man/* %{buildroot}%{_mandir}/man1/
%if 0%{?with_python3}
cp -a %{buildroot}%{_mandir}/man1/django-admin.1 %{buildroot}%{_mandir}/man1/python3-django-admin.1
%endif # with_python3

# install bash completion script
bashcompdir=$(pkg-config --variable=completionsdir bash-completion)
mkdir -p %{buildroot}$bashcompdir
install -m 0644 -p extras/django_bash_completion \
  %{buildroot}$bashcompdir/django-admin.py

for file in django-admin python3-django-admin manage.py ; do
   ln -s django-admin.py %{buildroot}$bashcompdir/$file
done

# Fix items in %%{_bindir}
mv %{buildroot}%{_bindir}/django-admin.py %{buildroot}%{_bindir}/django-admin

# remove .po files
find $RPM_BUILD_ROOT -name "*.po" | xargs rm -f

%check
%if 0%{?fedora} > 0
cd %{_builddir}/%{pkgname}-%{version}
export PYTHONPATH=$(pwd)
export LANG=en_US.utf8
cd tests
%{__python} ./runtests.py --settings=test_sqlite --verbosity=2 --parallel 1

%if 0%{?with_python3}
# strange, tests on py35 fail in koji, but pass in local mock
#{__python3} runtests.py --settings=test_sqlite --verbosity=2 --parallel 1
%endif # with_python3

%endif


%files -n python2-django -f django.lang
%doc AUTHORS README.rst
%license LICENSE
# manual pages are owned by both python2 and python3 packages
%{_mandir}/man1/*
# except the symlink with python3 prefix
%if 0%{?with_python3}
%exclude %{_mandir}/man1/python3-*
%endif # with_python3
%{_bindir}/django-admin
%attr(0755,root,root) %{python2_sitelib}/django/bin/django-admin.py*
# Include everything but the locale data ...
%dir %{python2_sitelib}/django
%dir %{python2_sitelib}/django/bin
%{python2_sitelib}/django/apps
%{python2_sitelib}/django/db/
%{python2_sitelib}/django/*.py*
%{python2_sitelib}/django/utils/
%{python2_sitelib}/django/dispatch/
%{python2_sitelib}/django/template/
%{python2_sitelib}/django/views/
%{python2_sitelib}/django/urls/
%dir %{python2_sitelib}/django/conf/
%dir %{python2_sitelib}/django/conf/locale/
%dir %{python2_sitelib}/django/conf/locale/??/
%dir %{python2_sitelib}/django/conf/locale/??_*/
%dir %{python2_sitelib}/django/conf/locale/*/LC_MESSAGES
%dir %{python2_sitelib}/django/contrib/
%{python2_sitelib}/django/contrib/*.py*
%dir %{python2_sitelib}/django/contrib/admin/
%dir %{python2_sitelib}/django/contrib/admin/locale
%dir %{python2_sitelib}/django/contrib/admin/locale/??/
%dir %{python2_sitelib}/django/contrib/admin/locale/??_*/
%dir %{python2_sitelib}/django/contrib/admin/locale/*/LC_MESSAGES
%{python2_sitelib}/django/contrib/admin/*.py*
%{python2_sitelib}/django/contrib/admin/migrations
%{python2_sitelib}/django/contrib/admin/views/
%{python2_sitelib}/django/contrib/admin/static/
%{python2_sitelib}/django/contrib/admin/templatetags/
%{python2_sitelib}/django/contrib/admin/templates/
%dir %{python2_sitelib}/django/contrib/admindocs/
%dir %{python2_sitelib}/django/contrib/admindocs/locale/
%dir %{python2_sitelib}/django/contrib/admindocs/locale/??/
%dir %{python2_sitelib}/django/contrib/admindocs/locale/??_*/
%dir %{python2_sitelib}/django/contrib/admindocs/locale/*/LC_MESSAGES
%{python2_sitelib}/django/contrib/admindocs/*.py*
%{python2_sitelib}/django/contrib/admindocs/templates/
%dir %{python2_sitelib}/django/contrib/auth/
%dir %{python2_sitelib}/django/contrib/auth/locale/
%dir %{python2_sitelib}/django/contrib/auth/locale/??/
%dir %{python2_sitelib}/django/contrib/auth/locale/??_*/
%dir %{python2_sitelib}/django/contrib/auth/locale/*/LC_MESSAGES
%{python2_sitelib}/django/contrib/auth/*.py*
%{python2_sitelib}/django/contrib/auth/common-passwords.txt.gz
%{python2_sitelib}/django/contrib/auth/handlers/
%{python2_sitelib}/django/contrib/auth/management/
%{python2_sitelib}/django/contrib/auth/migrations/
%{python2_sitelib}/django/contrib/auth/templates/
%{python2_sitelib}/django/contrib/auth/tests/
%dir %{python2_sitelib}/django/contrib/contenttypes/
%dir %{python2_sitelib}/django/contrib/contenttypes/locale
%dir %{python2_sitelib}/django/contrib/contenttypes/locale/??/
%dir %{python2_sitelib}/django/contrib/contenttypes/locale/??_*/
%dir %{python2_sitelib}/django/contrib/contenttypes/locale/*/LC_MESSAGES
%{python2_sitelib}/django/contrib/contenttypes/management
%{python2_sitelib}/django/contrib/contenttypes/migrations
%{python2_sitelib}/django/contrib/contenttypes/*.py*
%dir %{python2_sitelib}/django/contrib/flatpages/
%dir %{python2_sitelib}/django/contrib/flatpages/locale/
%dir %{python2_sitelib}/django/contrib/flatpages/locale/??/
%dir %{python2_sitelib}/django/contrib/flatpages/locale/??_*/
%dir %{python2_sitelib}/django/contrib/flatpages/locale/*/LC_MESSAGES
%{python2_sitelib}/django/contrib/flatpages/*.py*
%{python2_sitelib}/django/contrib/flatpages/migrations/
%{python2_sitelib}/django/contrib/flatpages/templatetags
%dir %{python2_sitelib}/django/contrib/gis/
%dir %{python2_sitelib}/django/contrib/gis/locale/
%dir %{python2_sitelib}/django/contrib/gis/locale/??/
%dir %{python2_sitelib}/django/contrib/gis/locale/??_*/
%dir %{python2_sitelib}/django/contrib/gis/locale/*/LC_MESSAGES
%{python2_sitelib}/django/contrib/gis/*.py*
%{python2_sitelib}/django/contrib/gis/geoip/
%{python2_sitelib}/django/contrib/gis/geoip2/
%{python2_sitelib}/django/contrib/gis/serializers/
%{python2_sitelib}/django/contrib/gis/static
%dir %{python2_sitelib}/django/contrib/humanize/
%dir %{python2_sitelib}/django/contrib/humanize/locale/
%dir %{python2_sitelib}/django/contrib/humanize/locale/??/
%dir %{python2_sitelib}/django/contrib/humanize/locale/??_*/
%dir %{python2_sitelib}/django/contrib/humanize/locale/*/LC_MESSAGES
%{python2_sitelib}/django/contrib/humanize/templatetags/
%{python2_sitelib}/django/contrib/humanize/*.py*
%{python2_sitelib}/django/contrib/messages/*.py*
%dir %{python2_sitelib}/django/contrib/postgres/
%{python2_sitelib}/django/contrib/postgres/*.py*
%{python2_sitelib}/django/contrib/postgres/aggregates
%{python2_sitelib}/django/contrib/postgres/jinja2
%{python2_sitelib}/django/contrib/postgres/fields
%{python2_sitelib}/django/contrib/postgres/forms
%{python2_sitelib}/django/contrib/postgres/templates
%dir %{python2_sitelib}/django/contrib/redirects
%dir %{python2_sitelib}/django/contrib/redirects/locale
%dir %{python2_sitelib}/django/contrib/redirects/locale/??/
%dir %{python2_sitelib}/django/contrib/redirects/locale/??_*/
%dir %{python2_sitelib}/django/contrib/redirects/locale/*/LC_MESSAGES
%{python2_sitelib}/django/contrib/redirects/*.py*
%{python2_sitelib}/django/contrib/redirects/migrations
%dir %{python2_sitelib}/django/contrib/sessions/
%dir %{python2_sitelib}/django/contrib/sessions/locale/
%dir %{python2_sitelib}/django/contrib/sessions/locale/??/
%dir %{python2_sitelib}/django/contrib/sessions/locale/??_*/
%dir %{python2_sitelib}/django/contrib/sessions/locale/*/LC_MESSAGES
%{python2_sitelib}/django/contrib/sessions/management/
%{python2_sitelib}/django/contrib/sessions/migrations/
%{python2_sitelib}/django/contrib/sessions/*.py*
%{python2_sitelib}/django/contrib/sitemaps/
%dir %{python2_sitelib}/django/contrib/sites/
%dir %{python2_sitelib}/django/contrib/sites/locale/
%dir %{python2_sitelib}/django/contrib/sites/locale/??/
%dir %{python2_sitelib}/django/contrib/sites/locale/??_*/
%dir %{python2_sitelib}/django/contrib/sites/locale/*/LC_MESSAGES
%{python2_sitelib}/django/contrib/sites/*.py*
%{python2_sitelib}/django/contrib/sites/migrations
%{python2_sitelib}/django/contrib/staticfiles/
%{python2_sitelib}/django/contrib/syndication/
%{python2_sitelib}/django/contrib/gis/admin/
%{python2_sitelib}/django/contrib/gis/db/
%{python2_sitelib}/django/contrib/gis/forms/
%{python2_sitelib}/django/contrib/gis/gdal/
%{python2_sitelib}/django/contrib/gis/geometry/
%{python2_sitelib}/django/contrib/gis/geos/
%{python2_sitelib}/django/contrib/gis/management/
%{python2_sitelib}/django/contrib/gis/sitemaps/
%{python2_sitelib}/django/contrib/gis/static/gis/js/OLMapWidget.js
%{python2_sitelib}/django/contrib/gis/templates/
%{python2_sitelib}/django/contrib/gis/utils/
%{python2_sitelib}/django/contrib/messages/storage/
%{python2_sitelib}/django/contrib/sessions/backends/
%{python2_sitelib}/django/forms/
%{python2_sitelib}/django/templatetags/
%{python2_sitelib}/django/core/
%{python2_sitelib}/django/http/
%{python2_sitelib}/django/middleware/
%{python2_sitelib}/django/test/
%{python2_sitelib}/django/conf/*.py*
%{python2_sitelib}/django/conf/project_template/
%{python2_sitelib}/django/conf/app_template/
%{python2_sitelib}/django/conf/urls/
%{python2_sitelib}/django/conf/locale/*/*.py*
%{python2_sitelib}/django/conf/locale/*.py*

%{python2_sitelib}/*.egg-info

%files -n python2-django-doc
# %doc docs/_build/html/*

%files bash-completion
%{_datadir}/bash-completion

%if 0%{?with_python3}
%files -n python3-django-doc
# %doc docs/_build/html/*

%files -n python3-django -f python3-django.lang
%doc AUTHORS README.rst
%license LICENSE
%{_bindir}/python3-django-admin
# as said before, manpages are owned by both python2 and python3 packages
%exclude %{_mandir}/man1/django-admin.1*
%{_mandir}/man1/python3-django-admin.1.*
%attr(0755,root,root) %{python3_sitelib}/django/bin/django-admin.py*
# Include everything but the locale data ...
%dir %{python3_sitelib}/django
%dir %{python3_sitelib}/django/bin
%{python3_sitelib}/django/apps
%{python3_sitelib}/django/db/
%{python3_sitelib}/django/*.py*
%{python3_sitelib}/django/utils/
%{python3_sitelib}/django/dispatch/
%{python3_sitelib}/django/template/
%{python3_sitelib}/django/urls/
%{python3_sitelib}/django/views/
%dir %{python3_sitelib}/django/conf/
%dir %{python3_sitelib}/django/conf/locale/
%dir %{python3_sitelib}/django/conf/locale/??/
%dir %{python3_sitelib}/django/conf/locale/??_*/
%dir %{python3_sitelib}/django/conf/locale/*/LC_MESSAGES
%dir %{python3_sitelib}/django/contrib/
%{python3_sitelib}/django/contrib/*.py*
%dir %{python3_sitelib}/django/contrib/admin/
%dir %{python3_sitelib}/django/contrib/admin/locale
%dir %{python3_sitelib}/django/contrib/admin/locale/??/
%dir %{python3_sitelib}/django/contrib/admin/locale/??_*/
%dir %{python3_sitelib}/django/contrib/admin/locale/*/LC_MESSAGES
%{python3_sitelib}/django/contrib/admin/*.py*
%{python3_sitelib}/django/contrib/admin/migrations
%{python3_sitelib}/django/contrib/admin/views/
%{python3_sitelib}/django/contrib/admin/static/
%{python3_sitelib}/django/contrib/admin/templatetags/
%{python3_sitelib}/django/contrib/admin/templates/
%dir %{python3_sitelib}/django/contrib/admindocs/
%dir %{python3_sitelib}/django/contrib/admindocs/locale/
%dir %{python3_sitelib}/django/contrib/admindocs/locale/??/
%dir %{python3_sitelib}/django/contrib/admindocs/locale/??_*/
%dir %{python3_sitelib}/django/contrib/admindocs/locale/*/LC_MESSAGES
%{python3_sitelib}/django/contrib/admindocs/*.py*
%{python3_sitelib}/django/contrib/admindocs/templates/
%dir %{python3_sitelib}/django/contrib/auth/
%dir %{python3_sitelib}/django/contrib/auth/locale/
%dir %{python3_sitelib}/django/contrib/auth/locale/??/
%dir %{python3_sitelib}/django/contrib/auth/locale/??_*/
%dir %{python3_sitelib}/django/contrib/auth/locale/*/LC_MESSAGES
%{python3_sitelib}/django/contrib/auth/*.py*
%{python3_sitelib}/django/contrib/auth/common-passwords.txt.gz
%{python3_sitelib}/django/contrib/auth/handlers/
%{python3_sitelib}/django/contrib/auth/management/
%{python3_sitelib}/django/contrib/auth/migrations/
%{python3_sitelib}/django/contrib/auth/templates/
%{python3_sitelib}/django/contrib/auth/tests/
%dir %{python3_sitelib}/django/contrib/contenttypes/
%dir %{python3_sitelib}/django/contrib/contenttypes/locale
%dir %{python3_sitelib}/django/contrib/contenttypes/locale/??/
%dir %{python3_sitelib}/django/contrib/contenttypes/locale/??_*/
%dir %{python3_sitelib}/django/contrib/contenttypes/locale/*/LC_MESSAGES
%{python3_sitelib}/django/contrib/contenttypes/*.py*
%{python3_sitelib}/django/contrib/contenttypes/__pycache__
%{python3_sitelib}/django/contrib/contenttypes/management/
%{python3_sitelib}/django/contrib/contenttypes/migrations/
%dir %{python3_sitelib}/django/contrib/flatpages/
%dir %{python3_sitelib}/django/contrib/flatpages/locale/
%dir %{python3_sitelib}/django/contrib/flatpages/locale/??/
%dir %{python3_sitelib}/django/contrib/flatpages/locale/??_*/
%dir %{python3_sitelib}/django/contrib/flatpages/locale/*/LC_MESSAGES
%{python3_sitelib}/django/contrib/flatpages/*.py*
%{python3_sitelib}/django/contrib/flatpages/migrations
%{python3_sitelib}/django/contrib/flatpages/templatetags
%dir %{python3_sitelib}/django/contrib/gis/
%dir %{python3_sitelib}/django/contrib/gis/locale/
%dir %{python3_sitelib}/django/contrib/gis/locale/??/
%dir %{python3_sitelib}/django/contrib/gis/locale/??_*/
%dir %{python3_sitelib}/django/contrib/gis/locale/*/LC_MESSAGES
%{python3_sitelib}/django/contrib/gis/*.py*
%{python3_sitelib}/django/contrib/gis/geoip/
%{python3_sitelib}/django/contrib/gis/geoip2/
%{python3_sitelib}/django/contrib/gis/serializers/
%{python3_sitelib}/django/contrib/gis/static/
%dir %{python3_sitelib}/django/contrib/humanize/
%dir %{python3_sitelib}/django/contrib/humanize/locale/
%dir %{python3_sitelib}/django/contrib/humanize/locale/??/
%dir %{python3_sitelib}/django/contrib/humanize/locale/??_*/
%dir %{python3_sitelib}/django/contrib/humanize/locale/*/LC_MESSAGES
%{python3_sitelib}/django/contrib/humanize/templatetags/
%{python3_sitelib}/django/contrib/humanize/*.py*
%dir %{python3_sitelib}/django/contrib/messages/
%{python3_sitelib}/django/contrib/messages/*.py*
%dir %{python3_sitelib}/django/contrib/postgres
%{python3_sitelib}/django/contrib/postgres/*.py*
%{python3_sitelib}/django/contrib/postgres/aggregates
%{python3_sitelib}/django/contrib/postgres/jinja2
%{python3_sitelib}/django/contrib/postgres/fields
%{python3_sitelib}/django/contrib/postgres/forms
%{python3_sitelib}/django/contrib/postgres/templates
%{python3_sitelib}/django/contrib/postgres/__pycache__
%dir %{python3_sitelib}/django/contrib/redirects
%dir %{python3_sitelib}/django/contrib/redirects/locale
%dir %{python3_sitelib}/django/contrib/redirects/locale/??/
%dir %{python3_sitelib}/django/contrib/redirects/locale/??_*/
%dir %{python3_sitelib}/django/contrib/redirects/locale/*/LC_MESSAGES
%{python3_sitelib}/django/contrib/redirects/*.py*
%{python3_sitelib}/django/contrib/redirects/migrations
%dir %{python3_sitelib}/django/contrib/sessions/
%dir %{python3_sitelib}/django/contrib/sessions/locale/
%dir %{python3_sitelib}/django/contrib/sessions/locale/??/
%dir %{python3_sitelib}/django/contrib/sessions/locale/??_*/
%dir %{python3_sitelib}/django/contrib/sessions/locale/*/LC_MESSAGES
%{python3_sitelib}/django/contrib/sessions/management/
%{python3_sitelib}/django/contrib/sessions/migrations/
%{python3_sitelib}/django/contrib/sessions/*.py*
%{python3_sitelib}/django/contrib/sitemaps/
%dir %{python3_sitelib}/django/contrib/sites/
%dir %{python3_sitelib}/django/contrib/sites/locale/
%dir %{python3_sitelib}/django/contrib/sites/locale/??/
%dir %{python3_sitelib}/django/contrib/sites/locale/??_*/
%dir %{python3_sitelib}/django/contrib/sites/locale/*/LC_MESSAGES
%{python3_sitelib}/django/contrib/sites/*.py*
%{python3_sitelib}/django/contrib/sites/migrations
%{python3_sitelib}/django/contrib/staticfiles/
%{python3_sitelib}/django/contrib/syndication/
%{python3_sitelib}/django/contrib/gis/admin/
%{python3_sitelib}/django/contrib/gis/db/
%{python3_sitelib}/django/contrib/gis/forms/
%{python3_sitelib}/django/contrib/gis/gdal/
%{python3_sitelib}/django/contrib/gis/geometry/
%{python3_sitelib}/django/contrib/gis/geos/
%{python3_sitelib}/django/contrib/gis/management/
%{python3_sitelib}/django/contrib/gis/sitemaps/
%{python3_sitelib}/django/contrib/gis/static/gis/js/OLMapWidget.js
%{python3_sitelib}/django/contrib/gis/templates/
%{python3_sitelib}/django/contrib/gis/utils/
%{python3_sitelib}/django/contrib/messages/storage/
%{python3_sitelib}/django/contrib/sessions/backends/
%{python3_sitelib}/django/forms/
%{python3_sitelib}/django/templatetags/
%{python3_sitelib}/django/core/
%{python3_sitelib}/django/http/
%{python3_sitelib}/django/middleware/
%{python3_sitelib}/django/test/
%{python3_sitelib}/django/conf/*.py*
%{python3_sitelib}/django/conf/project_template/
%{python3_sitelib}/django/conf/app_template/
%{python3_sitelib}/django/conf/urls/
%{python3_sitelib}/django/conf/locale/*/*.py*
%{python3_sitelib}/django/conf/locale/*.py*
%{python3_sitelib}/%{pkgname}-%{version}-py%{python3_version}.egg-info
%{python3_sitelib}/django/__pycache__
%{python3_sitelib}/django/bin/__pycache__
%{python3_sitelib}/django/conf/__pycache__
%{python3_sitelib}/django/conf/locale/*/__pycache__
%{python3_sitelib}/django/contrib/__pycache__
%{python3_sitelib}/django/contrib/admin/__pycache__
%{python3_sitelib}/django/contrib/admindocs/__pycache__
%{python3_sitelib}/django/contrib/auth/__pycache__
%{python3_sitelib}/django/contrib/flatpages/__pycache__
%{python3_sitelib}/django/contrib/gis/__pycache__
%{python3_sitelib}/django/contrib/humanize/__pycache__
%{python3_sitelib}/django/contrib/messages/__pycache__
%{python3_sitelib}/django/contrib/redirects/__pycache__
%{python3_sitelib}/django/contrib/sessions/__pycache__
%{python3_sitelib}/django/contrib/sites/__pycache__
%endif


%changelog
* Mon Nov 19 2018 Stephen Gallagher <sgallagh@redhat.com> - 1.11.13-4
- Drop %%{python_provide} macros introducing automatic Obsoletes

* Mon Nov 19 2018 Matthias Runge <mrunge@redhat.com> - 1.11.13-3
- drop all obsoletes

* Thu Nov 15 2018 Matthias Runge <mrunge@redhat.com> - 1.11.13-2
- rebase EPEL7 package to Django-1.11.x

* Mon May 21 2018 Miro Hrončok <mhroncok@redhat.com> - 1.11.13-2
- Make python2-django require python-django-bash-completion (as intended)

* Wed Apr 05 2017 Stephen Gallagher <sgallagh@redhat.com> - 1.6.11.6-1
- Update to the latest upstream security release 1.6.11.6
- https://www.reviewboard.org/news/2017/04/04/new-django-1-6-11-6-security-releases/

* Fri Mar 04 2016 Matthias Runge <mrunge@redhat.com> - 1.6.11-5
- fix CVE-2016-2512 (rhbz#1314345)
- fix CVE-2016-2513

* Mon Nov 30 2015 Matthias Runge <mrunge@redhat.com> - 1.6.11-4
- fix for CVE-2015-8213 (rhbz#1285279)
  backport thanks to https://github.com/beanbaginc/django/
- changed patches to use rdopkg for managing patches

* Wed Aug 26 2015 Matthias Runge <mrunge@redhat.com> - 1.6.11-3
- cherry-pick fix for Denial-of-service possibility in logout()
  view by filling session store CVE-2015-5963, CVE-2015-5964
- Prevented newlines from being accepted in some validators.

* Thu Jul 16 2015 Matthias Runge <mrunge@redhat.com> - 1.6.11-2
- cherry pick fix for CVE-2015-5143 (DoS by filling session store)
  rhbz#1239010

* Mon Mar 23 2015 Matthias Runge <mrunge@redhat.com> - 1.6.11-1
- fix CVE-2015-2316 (rhbz#1203615)
- fix CVE-2015-2317 (rhbz#1203618)

* Wed Jan 14 2015 Matthias Runge <mrunge@redhat.com> - 1.6.10-1
- fix CVE-2015-0219 (rhbz#1181939)
- fix CVE-2015-0220 (rhbz#1181943)
- fix CVE-2015-0221 (rhbz#1181946)
- fix CVE-2015-0222 (rhbz#1181951)

* Mon Jan 05 2015 Matthias Runge <mrunge@redhat.com> - 1.6.9-1
- update to 1.6.9

* Tue Nov 11 2014 Matthias Runge <mrunge@redhat.com> - 1.6.8-1
- update to 1.6.8

* Thu Sep 25 2014 Matthias Runge <mrunge@redhat.com> - 1.6.7-1
- update to 1.6.7
- don't own bash-completion dir.

* Thu Aug 21 2014 Matthias Runge <mrunge@redhat.com> - 1.6.6-1
- update to 1.6.6 
- fix CVE-2014-0480 (rhbz#1129950)
- fix CVE-2014-0481 (rhbz#1129952)
- fix CVE-2014-0482 (rhbz#1129954)
- fix CVE-2014-0483 (rhbz#1129959)

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.6.5-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Wed May 28 2014 Kalev Lember <kalevlember@gmail.com> - 1.6.5-2
- Rebuilt for https://fedoraproject.org/wiki/Changes/Python_3.4

* Fri May 16 2014 Matthias Runge <mrunge@redhat.com> - 1.6.5-1
- update to 1.6.5 CVE-2014-1418, CVE-2014-3730 (rhbz#1097935)

* Mon May 12 2014 Matthias Runge <mrunge@redhat.com> - 1.6.4-2
- don't hardcode python3.3

* Wed May 07 2014 Matthias Runge <mrunge@redhat.com> - 1.6.4-1
- update to 1.6.4 fix a potential regression in reverse()

* Tue Apr 22 2014 Matthias Runge <mrunge@redhat.com> - 1.6.3-1
- update to 1.6.3 fixing CVE-2014-0473 and CVE-2014-0474

* Thu Mar 27 2014 Matthias Runge <mrunge@redhat.com> - 1.6.2-2
- remove simplejson requirement
- make bash-completion a sub-package, both main packages can require

* Thu Feb 13 2014 Matthias Runge <mrunge@redhat.com> - 1.6.2-1
- update to 1.6.2 (rhbz#1027766)
- bash completion for python3-django-admin (rhbz#1035987)

* Mon Jan 27 2014 Matthias Runge <mrunge@redhat.com> - 1.5.4-3
- python-simplejson is not a hard requirement any more

* Thu Dec 19 2013 Dennis Gilmore <dennis@ausil.us> - 1.5.4-2
- disable python3 on epel7

* Sun Nov 24 2013 Matěj Cepl <mcepl@redhat.com> - 1.6-1
- update to 1.6 (rhbz#1027766)

* Tue Oct 29 2013 Matthias Runge <mrunge@redhat.com> - 1.5.5-2
- fix obsoletes

* Mon Oct 28 2013 Matthias Runge <mrunge@redhat.com> - 1.5.5-1
- update to 1.5.5 (rhbz#1023407)

* Mon Sep 16 2013 Matthias Runge <mrunge@redhat.com> - 1.5.4-1
- fix CVE-2013-1443 (DoS via large passwords), fixes rhbz#1008281

* Wed Sep 11 2013 Matthias Runge <mrunge@redhat.com> - 1.5.3-1
- fix CVE-2013-4315 (ssi issue), fixes rhbz 1004969

* Tue Aug 20 2013 Matthias Runge <mrunge@redhat.com> - 1.5.2-2
- increase obsoletes to 1.4.6-2

* Wed Aug 14 2013 Matthias Runge <mrunge@redhat.com> - 1.5.2-1
- security related update

* Mon Aug 05 2013 Matthias Runge <mrunge@redhat.com> - 1.5.1-3
- rebuild to fix build issues during mass rebuild.

* Sun Aug 04 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.5.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Tue Apr 02 2013 Matthias Runge <mrunge@redhat.com> - 1.5.1-1
- update to Django-1.5.1 (rhbz#929413)

* Wed Mar 27 2013 Miro Hrončok <mhroncok@redhat.com> - 1.5-3
- separated lang files for Python 2 and 3
- list %%files in Python 3 subpackage more precisely to not include locale files
- added %%doc to Python 3 subpackage
- removed trailing slash after %%{buildroot} to avoid double slash
- fixed bogus dates in %%changelog
- made %%check verbose, so it is not so boring to watch them run
- created python3 doc package
- created python3- prefixed symlink to manpage
- comment added about shared content - manpages

* Wed Mar 27 2013 Bohuslav Kabrda <bkabrda@redhat.com> - 1.5-2
- Make the python3 subpackage install first, so that django-admin
  doesn't get overwritten.
- Don't own %%{python3_sitelib} itself, but only its contents.
